@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/tarsius/hl-todo
 ;; Keywords: convenience
 
-;; Package-Version: 3.8.2
+;; Package-Version: 3.8.3
 ;; Package-Requires: ((emacs "26.1") (compat "30.0.2.0"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -157,6 +157,12 @@ a Grep implementation other than GNU's, then that may break
                (hl-todo-mode -1)
                (hl-todo-mode 1))))))
 
+(defface hl-todo-flymake-type '((t :inherit font-lock-keyword-face))
+  "Face used for the Flymake diagnostics type `hl-todo-flymake'.
+This is used for the word \"todo\" appearing in the \"Type\" column
+of buffers created by `flymake-show-buffer-diagnostics' and similar."
+  :group 'hl-todo)
+
 (defcustom hl-todo-color-background nil
   "Whether to emphasize keywords using the background color.
 
@@ -402,7 +408,8 @@ enabling `flymake-mode'."
           (save-match-data
             (goto-char (point-min))
             (while (hl-todo--search)
-              (let ((beg (match-beginning 0))
+              (let ((keyword (match-string 1))
+                    (beg (match-beginning 0))
                     (end (pos-eol))
                     (bol (pos-bol)))
                 ;; Take whole line when keyword is not at the start of comment.
@@ -417,12 +424,25 @@ enabling `flymake-mode'."
                     ;; Skip comment.
                     (re-search-forward comment beg t)
                     (setq beg (point))))
-                (push (flymake-make-diagnostic
-                       buf beg end :note
-                       (buffer-substring-no-properties beg end))
+                (push (hl-todo-make-flymake-diagnostic
+                       buf beg end (buffer-substring-no-properties beg end)
+                       keyword)
                       diags)))))))
     (funcall report-fn (nreverse diags))))
 
+;; Advise this function if you want multiple keyword types.
+(defun hl-todo-make-flymake-diagnostic (locus beg end text _keyword)
+  (flymake-make-diagnostic locus beg end 'hl-todo-flymake text))
+(put 'hl-todo-flymake 'flymake-category 'flymake-note)
+(put 'hl-todo-flymake 'flymake-type-name "todo")
+;; Do not underline lines containing TODO keyword.
+(put 'hl-todo-flymake 'face nil)
+;; As of Emacs 30.0.50, we have to set this property to control
+;; the face that is used *inside* the list buffer.  This face
+;; is *not* used in the mode-line (where the respective face of
+;; the `flymake-note' category is used instead).
+(put 'hl-todo-flymake 'mode-line-face 'hl-todo-flymake-type)
+
 ;;;###autoload
 (defun hl-todo-insert (keyword)
   "Read a TODO or similar keyword and insert it at point.
